@@ -99,6 +99,9 @@ module System.Random.MWC
 
 import Control.Monad           (ap, liftM, unless)
 import Control.Monad.Primitive (PrimMonad, PrimState, unsafePrimToIO)
+#if MIN_VERSION_primitive(0,6,0)
+import Control.Monad.Primitive (PrimBase)
+#endif
 import Control.Monad.ST        (ST)
 import Data.Bits               (Bits, (.&.), (.|.), shiftL, shiftR, xor)
 import Data.Int                (Int8, Int16, Int32, Int64)
@@ -428,11 +431,17 @@ acquireSeedSystem = do
 -- Cryptographic API as a source of random numbers (it uses the system
 -- clock instead). As a result, the sequences it generates may not be
 -- highly independent.
-withSystemRandom :: PrimMonad m => (Gen (PrimState m) -> m a) -> IO a
+withSystemRandom ::
+#if MIN_VERSION_primitive(0,6,0)
+                    PrimBase m
+#else
+                    PrimMonad m
+#endif
+                 => (Gen (PrimState m) -> m a) -> IO a
 withSystemRandom act = do
   seed <- acquireSeedSystem `E.catch` \(_::E.IOException) -> do
     seen <- atomicModifyIORef warned ((,) True)
-    unless seen $ do
+    unless seen $ E.handle (\(_::E.IOException) -> return ()) $ do
       hPutStrLn stderr ("Warning: Couldn't open /dev/urandom")
       hPutStrLn stderr ("Warning: using system clock for seed instead " ++
                         "(quality will be lower)")
