@@ -4,18 +4,19 @@ import Control.Monad
 import System.Directory  (createDirectoryIfMissing,setCurrentDirectory)
 import System.IO
 
-import qualified System.Random.MWC               as MWC
-import qualified System.Random.MWC.Distributions as MWC
+import qualified System.Random.MWC                as MWC
+import qualified System.Random.MWC.Distributions  as MWC
+import qualified System.Random.MWC.CondensedTable as MWC
 
 
 dumpSample :: Show a => Int -> FilePath -> IO a -> IO ()
 dumpSample n fname gen =
   withFile fname WriteMode $ \h -> 
     replicateM_ n (hPutStrLn h . show =<< gen)
-  
+
 main :: IO ()
 main = MWC.withSystemRandom $ \g -> do
-  let n   = 10000
+  let n   = 30000
       dir = "distr"
   createDirectoryIfMissing True dir
   setCurrentDirectory           dir
@@ -31,3 +32,13 @@ main = MWC.withSystemRandom $ \g -> do
   -- Exponential
   dumpSample n "exponential-1" $ MWC.exponential 1 g
   dumpSample n "exponential-3" $ MWC.exponential 3 g
+  -- Poisson
+  dumpSample n "poisson-0.1"   $ MWC.genFromTable (MWC.tablePoisson 0.1) g
+  dumpSample n "poisson-1.0"   $ MWC.genFromTable (MWC.tablePoisson 1.0) g
+  dumpSample n "poisson-4.5"   $ MWC.genFromTable (MWC.tablePoisson 4.5) g
+  dumpSample n "poisson-30"    $ MWC.genFromTable (MWC.tablePoisson 30)  g
+  -- Binomial
+  dumpSample n "binom-4-0.5"   $ MWC.genFromTable (MWC.tableBinomial 4  0.5) g
+  dumpSample n "binom-10-0.1"  $ MWC.genFromTable (MWC.tableBinomial 10 0.1) g  
+  dumpSample n "binom-10-0.6"  $ MWC.genFromTable (MWC.tableBinomial 10 0.6) g
+  dumpSample n "binom-10-0.8"  $ MWC.genFromTable (MWC.tableBinomial 10 0.8) g
